==> haskell-pager-0.1.1.0-53-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pager
version:              0.1.1.0
visibility:           public
id:                   pager-0.1.1.0-6KhKGSPQ1VDHSzIqE3acHU
key:                  pager-0.1.1.0-6KhKGSPQ1VDHSzIqE3acHU
license:              BSD-2-Clause
copyright:            Copyright (c) 2015, Peter Harpending.
maintainer:           peter@harpending.org
author:               Peter Harpending
homepage:             https://github.com/pharpend/pager
synopsis:             Open up a pager, like '\''less'\'' or '\''more'\''
description:
    This opens up the user'\''s $PAGER. On Linux, this is usually called @less@. On
    the various BSDs, this is usually @more@.

    CHANGES

    [0.1.1.0] Add @printOrPage@ function and @sendToPagerStrict@ function.

category:             Data, System, Text
abi:                  8b8534b2933c4a35e1cddd589cade1fb
exposed:              True
exposed-modules:      System.Pager
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pager-0.1.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pager-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pager
hs-libraries:         HSpager-0.1.1.0-6KhKGSPQ1VDHSzIqE3acHU
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    conduit-1.3.5-m4mJvLp39j4uQ7WG40JEh
    conduit-extra-1.3.6-G9k7JLYdKI7EqfyGYpmgB2 directory-1.3.6.2
    process-1.6.16.0 resourcet-1.2.6-5BnvDTZXmqJCsWMY1Zflgy
    safe-0.3.21-iv9yHEgDynJNZkwcC9KXL terminfo-0.4.1.5 text-1.2.5.0
    transformers-0.5.6.2 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-pager/html/pager.haddock
haddock-html:         /usr/share/doc/haskell-pager/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pager-0.1.1.0-66-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pager
version:              0.1.1.0
visibility:           public
id:                   pager-0.1.1.0-BKAooBNrejd3zUQ4BDsqKR
key:                  pager-0.1.1.0-BKAooBNrejd3zUQ4BDsqKR
license:              BSD-2-Clause
copyright:            Copyright (c) 2015, Peter Harpending.
maintainer:           peter@harpending.org
author:               Peter Harpending
homepage:             https://github.com/pharpend/pager
synopsis:             Open up a pager, like '\''less'\'' or '\''more'\''
description:
    This opens up the user'\''s $PAGER. On Linux, this is usually called @less@. On
    the various BSDs, this is usually @more@.

    CHANGES

    [0.1.1.0] Add @printOrPage@ function and @sendToPagerStrict@ function.

category:             Data, System, Text
abi:                  c760088b3e077bb68c1401e09b85f762
exposed:              True
exposed-modules:      System.Pager
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pager-0.1.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pager-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pager
hs-libraries:         HSpager-0.1.1.0-BKAooBNrejd3zUQ4BDsqKR
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    conduit-1.3.6-6d8V4DJENsC1laAutlfv9x
    conduit-extra-1.3.6-GQSgUNMr0ZN9ENRzkRi4eD directory-1.3.6.2
    process-1.6.16.0 resourcet-1.2.6-KSYfCEph27i1WbA0p8CCrD
    safe-0.3.21-98IVtOx0Wmj8cqPHUtTkEF terminfo-0.4.1.5 text-1.2.5.0
    transformers-0.5.6.2 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-pager/html/pager.haddock
haddock-html:         /usr/share/doc/haskell-pager/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
